@@ -3,7 +3,7 @@
  * @author Marko Mkel <msmakela@nic.funet.fi>
  */
 
-/* Copyright  2003 Marko Mkel.
+/* Copyright  2003,2004 Marko Mkel.
 
    This file is part of JPEGCOM, a program for reading and writing
    comments in digital photographs.
@@ -44,6 +44,8 @@
 #include <ctype.h>
 #include <locale.h>
 
+#include "rename.h"
+
 /** Read 16 bits from file, most significant byte first
  * @param file	the file
  * @return	the data read
@@ -389,39 +391,20 @@ touch_file (const char* name,
   int status;
   struct stat statbuf;
   if ((status = stat (ref, &statbuf))) {
-    (void) fputs (ref, stderr);
+    (void) fputs (ref, stderr), (void) fflush (stderr);
     perror (": stat");
   }
   else {
     struct utimbuf utim;
     utim.actime = utim.modtime = statbuf.st_mtime;
     if ((status = utime (name, &utim))) {
-      (void) fputs (ref, stderr);
+      (void) fputs (ref, stderr), (void) fflush (stderr);
       perror (": utime");
     }
   }
   return status;
 }
 
-/** Rename a file
- * @param old	the old file name
- * @param new	the new file name
- * @return	zero if successful
- */
-static int
-rename_file (const char* old,
-	     const char* new)
-{
-  int status = rename (old, new);
-  if (status) {
-    (void) fputs (old, stderr);
-    (void) fputs (" -> ", stderr);
-    (void) fputs (new, stderr);
-    perror (": rename");
-  }
-  return status;
-}
-
 /** Remove a hard link to a file
  * @param name	the file name to be removed
  * @return	zero if successful
@@ -431,7 +414,7 @@ remove_file (const char* name)
 {
   int status = unlink (name);
   if (status) {
-    (void) fputs (name, stderr);
+    (void) fputs (name, stderr), (void) fflush (stderr);
     perror (": unlink");
   }
   return status;
@@ -475,7 +458,7 @@ main (int argc, char** argv)
       FILE* f = fopen (argv[i], "rb");
       const char* s;
       if (!f) {
-	(void) fputs (argv[i], stderr);
+	(void) fputs (argv[i], stderr), (void) fflush (stderr);
 	perror (": open (reading)");
 	return 1;
       }
@@ -551,7 +534,7 @@ main (int argc, char** argv)
 	  FILE* out;
 	  int fd;
 	  if (!(in = fopen (name1, "rb"))) {
-	    (void) fputs (name1, stderr);
+	    (void) fputs (name1, stderr), (void) fflush (stderr);
 	    perror (": open (reading)");
 	    free (name1), free (name2);
 	    return 1;
@@ -572,7 +555,7 @@ main (int argc, char** argv)
 #endif
 		     );
 	  if (fd < 0 || !(out = fdopen (fd, "wb"))) {
-	    (void) fputs (name2, stderr);
+	    (void) fputs (name2, stderr), (void) fflush (stderr);
 	    perror (": open (writing)");
 	  cleanup:
 	    free (name1), free (name2);
@@ -587,12 +570,12 @@ main (int argc, char** argv)
 	    goto cleanup;
 	  }
 	  if (fclose (in)) {
-	    (void) fputs (name1, stderr);
+	    (void) fputs (name1, stderr), (void) fflush (stderr);
 	    perror (": close");
 	    /* ignore failure to close input file */
 	  }
 	  if (fclose (out)) {
-	    (void) fputs (name2, stderr);
+	    (void) fputs (name2, stderr), (void) fflush (stderr);
 	    perror (": close");
 	    /* abort on failure to close output file */
 	    goto cleanup;
