@@ -4,7 +4,7 @@
  * @author Marko Mkel (msmakela@nic.funet.fi)
  */
 
-/* Copyright  2003 Marko Mkel.
+/* Copyright  2003,2004 Marko Mkel.
 
    This file is part of JPEGNAIL, a program for removing or embedding
    JPEG thumbnails in images in Exif or JFIF format.
@@ -45,6 +45,7 @@
 #include <string.h>
 #include <setjmp.h>
 #include "scale.h"
+#include "rename.h"
 #include "jerror.h"
 
 /** Copy the timestamp of a file to another
@@ -59,14 +60,14 @@ touch_file (const char* name,
   int status;
   struct stat statbuf;
   if ((status = stat (ref, &statbuf))) {
-    (void) fputs (ref, stderr);
+    (void) fputs (ref, stderr), (void) fflush (stderr);
     perror (": stat");
   }
   else {
     struct utimbuf utim;
     utim.actime = utim.modtime = statbuf.st_mtime;
     if ((status = utime (name, &utim))) {
-      (void) fputs (ref, stderr);
+      (void) fputs (ref, stderr), (void) fflush (stderr);
       perror (": utime");
     }
   }
@@ -114,20 +115,12 @@ exif_output_message (struct jpeg_common_struct* cinfo)
 /** error messages from the Exif parser */
 static const char* exif_message_table[] = {
   0,
-  "Exif: unknown byte order",
-  "Exif: IFD0 offset out of bounds",
-  "Exif: premature end of IFD0",
-  "Exif: IFD1 offset out of bounds",
   "thumbnail image is too large (try smaller -q, -x or -y)",
 };
 
 /** error codes from the Exif parser */
 enum exif_message {
   EXIF_FIRSTCODE = 1000,	/**< first message code */
-  EXIF_UNKNOWN_ENDIAN,		/**< unknown byte order */
-  EXIF_IFD0_OOB,		/**< IFD0 out of bounds */
-  EXIF_IFD0_EOF,		/**< unexpected end of IFD0 */
-  EXIF_IFD1_OOB,		/**< IFD1 out of bounds */
   THUMBNAIL_WRITE,		/**< transformed thumbnail too large */
   EXIF_LASTCODE
 };
@@ -323,7 +316,7 @@ copy_markers (struct jpeg_decompress_struct* srcinfo,
 	GETJOCTET (marker->data[3]) == (JOCTET) 0x62 &&
 	GETJOCTET (marker->data[4]) == (JOCTET) 0x65)
       continue; /* reject duplicate Adobe */
-    if (thumb_length &&
+    if (thumb_length && exif_endian != UNKNOWN &&
 	marker->marker == (UINT8) (JPEG_APP0 + 1) &&
 	marker->data_length >= 8 &&
 	GETJOCTET (marker->data[0]) == (JOCTET) 0x45 &&
@@ -443,30 +436,59 @@ exif_parse (struct jpeg_decompress_struct* cinfo)
 	     GETJOCTET (marker->data[8]) == (JOCTET) 0x2a &&
 	     GETJOCTET (marker->data[9]) == (JOCTET) 0x00)
       exif_endian = LSB;
-    else
-      ERREXIT (cinfo, EXIF_UNKNOWN_ENDIAN);
+    else {
+      fprintf (stderr, "%s: ignoring Exif marker with byte order "
+	       "0x%02x%02x%02x%02x\n",
+	       srcname,
+	       (unsigned char) GETJOCTET (marker->data[6]),
+	       (unsigned char) GETJOCTET (marker->data[7]),
+	       (unsigned char) GETJOCTET (marker->data[8]),
+	       (unsigned char) GETJOCTET (marker->data[9]));
+      continue;
+    }
 
     /* Get first IFD offset (offset to IFD0) */
     offset = exif_read4 (&marker->data[10]);
-    if (offset > (unsigned long) marker->data_length - (10 + 2))
-      ERREXIT (cinfo, EXIF_IFD0_OOB);
+    if (offset > (unsigned long) marker->data_length - (10 + 2)) {
+      fprintf (stderr, "%s: Exif IFD0 offset out of bounds: %lu>%lu\n",
+	       srcname,
+	       offset, (unsigned long) marker->data_length - (10 + 2));
+    errexit:
+      fprintf (stderr, "%s: leaving Exif block intact due to errors\n",
+	       srcname);
+      exif_endian = UNKNOWN;
+      thumb_length = 0;
+      return;
+    }
     else {
       /** pointer to the start of the Exif data */
       JOCTET FAR* exif_data = &marker->data[6];
       /** offset to IFD1 */
-      unsigned ifd1_offset;
+      unsigned long ifd1_offset;
       /** length of Exif data */
       unsigned exif_length = marker->data_length - 6;
 
       /* Get the number of IFD0 entries */
       offset += 2 + 12 * exif_read2 (&exif_data[offset]);
-      if (offset > exif_length - 4)
-	ERREXIT (cinfo, EXIF_IFD0_EOF);
+      if (offset > exif_length - 4) {
+	fprintf (stderr, "%s: Exif IFD0 ends prematurely\n", srcname);
+	goto errexit;
+      }
       ifd1_offset = exif_read4 (&exif_data[offset]);
-      if (ifd1_offset &&
-	  (ifd1_offset < offset + 4 ||
-	   ifd1_offset > exif_length - 2))
-	ERREXIT (cinfo, EXIF_IFD1_OOB);
+      if (ifd1_offset) {
+	if (ifd1_offset < offset + 4) {
+	  fprintf (stderr, "%s: Exif IFD1 offset out of bounds: %lu<%lu\n",
+		   srcname,
+		   ifd1_offset, offset + 4);
+	  goto errexit;
+	}
+	else if (ifd1_offset > exif_length - 2) {
+	  fprintf (stderr, "%s: Exif IFD1 offset out of bounds: %lu>%lu\n",
+		   srcname,
+		   ifd1_offset, (unsigned long) exif_length - 2);
+	  goto errexit;
+	}
+      }
       if (ifd1_offset) {
 	/* remove the existing IFD1 */
 	exif_length = ifd1_offset;
@@ -550,6 +572,10 @@ jpeg_transform (struct jpeg_decompress_struct* srcinfo,
   static FILE* src = 0;
   /** output file */
   static FILE* dst = 0;
+
+  /* clear possible previous errors */
+  errno = 0;
+
   /* set up jump context for input */
   if (setjmp (((struct exif_error_mgr*) srcinfo->err)->setjmp_buffer)) {
     if (errno)
@@ -576,7 +602,7 @@ jpeg_transform (struct jpeg_decompress_struct* srcinfo,
   }
 
   if (dstname && !(src = fopen (srcname, "rb"))) {
-    (void) fputs (srcname, stderr);
+    (void) fputs (srcname, stderr), (void) fflush (stderr);
     perror (": open (reading)");
     return 1;
   }
@@ -599,7 +625,7 @@ jpeg_transform (struct jpeg_decompress_struct* srcinfo,
       goto ignore; /* thumbnail too large */
     /* re-read the file after constructing the thumbnail */
     if (fseek (src, 0, SEEK_SET)) {
-      (void) fputs (srcname, stderr);
+      (void) fputs (srcname, stderr), (void) fflush (stderr);
       perror (": fseek");
       goto ignore;
     }
@@ -623,7 +649,7 @@ jpeg_transform (struct jpeg_decompress_struct* srcinfo,
 #endif
 	       );
     if (fd < 0 || !(dst = fdopen (fd, "wb"))) {
-      (void) fputs (dstname, stderr);
+      (void) fputs (dstname, stderr), (void) fflush (stderr);
       perror (": open (writing)");
       (void) fclose (src);
       return 2;
@@ -656,13 +682,13 @@ jpeg_transform (struct jpeg_decompress_struct* srcinfo,
   copy_markers (srcinfo, dstinfo);
   jpeg_finish_compress (dstinfo);
   if (src && fclose (src)) {
-    (void) fputs (srcname, stderr);
-    perror ("close");
+    (void) fputs (srcname, stderr), (void) fflush (stderr);
+    perror (": close");
     /* ignore error on closing input file */
   }
   if (dst && fclose (dst)) {
-    (void) fputs (dstname, stderr);
-    perror ("close");
+    (void) fputs (dstname, stderr), (void) fflush (stderr);
+    perror (": close");
     return 2;
   }
   return 0;
@@ -723,7 +749,7 @@ main (int argc, char **argv)
       case '?':
       case 'h':
 	(void) fputs
-	  ("jpegnail 1.2.1\n"
+	  ("jpegnail 1.2.2\n"
 	   "Remove or embed thumbnails in Exif or JFIF JPEG images\n"
 	   "Usage: jpegnail [options] file ...\n"
 	   "Options:\n"
@@ -762,18 +788,17 @@ main (int argc, char **argv)
 	}
 	else {
 	  /* make sure that the specified directory exists */
-	  imagedirlen = strlen (*argv);
 #if defined WIN32 || defined __WIN32
 	  char* s = *argv;
 	  while (*s) if (*s++ == '\\') s[-1] = '/';
 #endif
-	  imagedir = *argv;
+	  imagedirlen = strlen (imagedir = *argv);
 	  if (mkdir (*argv
 #if !defined WIN32 && !defined __WIN32
 		     , 0777
 #endif
 		     ) && errno != EEXIST) {
-	    (void) fputs (*argv, stderr);
+	    (void) fputs (*argv, stderr), (void) fflush (stderr);
 	    perror (": mkdir");
 	    goto quit;
 	  }
@@ -788,7 +813,7 @@ main (int argc, char **argv)
 	    memcpy (s, *argv, imagedirlen);
 	    memcpy (s + imagedirlen, "/.", 3);
 	    if (stat (s, &statbuf)) {
-	      (void) fputs (s, stderr);
+	      (void) fputs (s, stderr), (void) fflush (stderr);
 	      perror (": stat");
 	      free (s);
 	      goto quit;
@@ -852,11 +877,7 @@ main (int argc, char **argv)
       jpeg_transform (&srcinfo, &dstinfo, dstname, progressive);
       if (!opts) {
 	(void) touch_file (dstname, srcname);
-	if (!imagedir && rename (dstname, srcname)) {
-	  (void) fputs (dstname, stderr);
-	  (void) fputs (" -> ", stderr);
-	  (void) fputs (srcname, stderr);
-	  perror (": rename");
+	if (!imagedir && rename_file (dstname, srcname)) {
 	quit:
 	  free (dstname), dstname = 0;
 	  status = 3;
