@@ -4,7 +4,7 @@
  * @author Marko Mkel <msmakela@nic.funet.fi>
  */
 
-/* Copyright  2003 Marko Mkel.
+/* Copyright  2003,2004 Marko Mkel.
 
    This file is part of PHOTOMOLO, a program for generating
    thumbnail images and HTML files for browsing digital photographs.
@@ -120,7 +120,7 @@ make_thumbnails (const struct dirtree* dir,
     fn = s;
     memcpy (fn + fnlen, dir->files[i].name, namelen);
     if (!(input = fopen (fn, "rb"))) {
-      (void) fputs (fn, stderr);
+      (void) fputs (fn, stderr), (void) fflush (stderr);
       perror (": open");
       free (fn);
       return 2;
@@ -145,7 +145,7 @@ make_thumbnails (const struct dirtree* dir,
       if (!exists_mtime (fn, dir->files[i].mtime)) {
 	FILE* output = fopen (fn, "wb");
 	if (!output) {
-	  (void) fputs (fn, stderr);
+	  (void) fputs (fn, stderr), (void) fflush (stderr);
 	  perror (": open (writing)");
 	  goto errexit;
 	}
@@ -158,7 +158,7 @@ make_thumbnails (const struct dirtree* dir,
 	  goto errexit;
 	}
 	if (fclose (output)) {
-	  (void) fputs (fn, stderr);
+	  (void) fputs (fn, stderr), (void) fflush (stderr);
 	  perror (": close");
 	  goto errexit;
 	}
@@ -168,7 +168,7 @@ make_thumbnails (const struct dirtree* dir,
     }
     if (fclose (input)) {
       memcpy (fn + fnlen, dir->files[i].name, namelen);
-      (void) fputs (fn, stderr);
+      (void) fputs (fn, stderr), (void) fflush (stderr);
       perror (": close"); /* report but otherwise ignore the error */
     }
   }
@@ -231,7 +231,7 @@ dumphtmls (const struct dirtree* tree,
     filename[dirnamelen + speclen - 1] = '/';
     memcpy (filename + dirnamelen + speclen, hopts.html, indexnamelen);
     if (!(f = fopen (filename, "wb"))) {
-      (void) fputs (filename, stderr);
+      (void) fputs (filename, stderr), (void) fflush (stderr);
       perror (": open");
       free (filename);
       return 1;
@@ -239,7 +239,7 @@ dumphtmls (const struct dirtree* tree,
     status = dumphtml (f, tree, level, info, comm, &hopts, thumbs, spec,
 		       top, prev, next);
     if (fclose (f) || status) {
-      (void) fputs (filename, stderr);
+      (void) fputs (filename, stderr), (void) fflush (stderr);
       perror (status ? ": write" : ": close");
       if (!status)
 	status = -1;
@@ -312,7 +312,7 @@ dumpfiles (const struct dirtree* tree,
       filename = s;
       memcpy (filename + dirnamelen, tree->files[i].name, len);
       if (!(f = fopen (filename, "rb"))) {
-	(void) fputs (filename, stderr);
+	(void) fputs (filename, stderr), (void) fflush (stderr);
 	perror (": fopen");
 	continue; /* ignore unreadable files */
       }
@@ -441,14 +441,14 @@ create_css (const char* path)
   if ((f = fopen (s, "rt")))
     goto done;
   if (!(f = fopen (s, "wt"))) {
-    (void) fputs (s, stderr);
+    (void) fputs (s, stderr), (void) fflush (stderr);
     perror (": open (writing)");
     free (s);
     return 2;
   }
   if ((sizeof css1) - 1 != fwrite (css1, 1, (sizeof css1) - 1, f) ||
       (sizeof css2) - 1 != fwrite (css2, 1, (sizeof css2) - 1, f)) {
-    (void) fputs (s, stderr);
+    (void) fputs (s, stderr), (void) fflush (stderr);
     perror (": write");
     free (s);
     (void) fclose (f);
@@ -477,7 +477,7 @@ main (int argc, char** argv)
   if (argc == 1) {
   Usage:
     (void) fputs
-      ("pHoToMoLo 1.2.1\n"
+      ("pHoToMoLo 1.2.2\n"
        "Create thumbnails and HTML navigation\n"
        "Usage: photomolo [options] directory1 directory2 ...\n"
        "Options:\n"
