@@ -77,9 +77,9 @@ color_transform (const struct jpeg_decompress_struct* cin,
 	m = GETJSAMPLE (*buf++);
 	y = GETJSAMPLE (*buf++);
 	k = GETJSAMPLE (*buf++);
-	*dst++ = (k * c) / MAXJSAMPLE;
-	*dst++ = (k * m) / MAXJSAMPLE;
-	*dst++ = (k * y) / MAXJSAMPLE;
+	*dst++ = (JSAMPLE) ((k * c) / MAXJSAMPLE);
+	*dst++ = (JSAMPLE) ((k * m) / MAXJSAMPLE);
+	*dst++ = (JSAMPLE) ((k * y) / MAXJSAMPLE);
       }
     }
     else {
@@ -88,9 +88,9 @@ color_transform (const struct jpeg_decompress_struct* cin,
 	m = MAXJSAMPLE - GETJSAMPLE (*buf++);
 	y = MAXJSAMPLE - GETJSAMPLE (*buf++);
 	k = MAXJSAMPLE - GETJSAMPLE (*buf++);
-	*dst++ = (k * c) / MAXJSAMPLE;
-	*dst++ = (k * m) / MAXJSAMPLE;
-	*dst++ = (k * y) / MAXJSAMPLE;
+	*dst++ = (JSAMPLE) ((k * c) / MAXJSAMPLE);
+	*dst++ = (JSAMPLE) ((k * m) / MAXJSAMPLE);
+	*dst++ = (JSAMPLE) ((k * y) / MAXJSAMPLE);
       }
     }
   }
@@ -142,7 +142,7 @@ rescale_jpeg (struct jpeg_decompress_struct* cin,
   /** pixel counter */
   unsigned x;
   /** number of colour components */
-  unsigned comps;
+  int comps;
   /** flag: need to read a row? */
   int need_row;
 
@@ -178,11 +178,11 @@ rescale_jpeg (struct jpeg_decompress_struct* cin,
 
   while (cout->next_scanline < cout->image_height) {
     if (cin->output_height == cout->image_height)
-      jpeg_read_scanlines (cin, inrow1, 1);
+      (void) jpeg_read_scanlines (cin, inrow1, 1);
     else {
       while (yleft < yfrac) {
 	if (need_row && cin->output_scanline < cin->output_height)
-	  jpeg_read_scanlines (cin, inrow1, 1);
+	  (void) jpeg_read_scanlines (cin, inrow1, 1);
 	for (x = cin->output_width * comps; x--; )
 	  pix[x] += yleft * GETJSAMPLE ((*inrow1)[x]);
 	yfrac -= yleft;
@@ -190,7 +190,7 @@ rescale_jpeg (struct jpeg_decompress_struct* cin,
 	need_row = 1;
       }
       if (need_row && cin->output_scanline < cin->output_height) {
-	jpeg_read_scanlines (cin, inrow1, 1);
+	(void) jpeg_read_scanlines (cin, inrow1, 1);
 	need_row = 0;
       }
       for (x = cin->output_width * comps; x--; ) {
@@ -218,7 +218,7 @@ rescale_jpeg (struct jpeg_decompress_struct* cin,
       /** number of fractional rows to read */
       float xleft;
       /** colour component counter */
-      unsigned c;
+      int c;
       /* clear the colour components */
       for (c = comps; c--; )
 	newpix[c] = 0.0;
@@ -322,6 +322,7 @@ scale_prepare (struct jpeg_decompress_struct* cin,
   case JCS_YCCK:
     /* convert YCCK via CMYK */
     cin->out_color_space = JCS_CMYK;
+    /*@fallthrough@*/
   case JCS_CMYK:
     /* convert CMYK to YCbCr via RGB */
     cout->in_color_space = JCS_RGB;
