@@ -39,22 +39,24 @@ parse_spec (const char* spec)
   char* d;
   struct thumb_spec* thumb;
   if (!c) {
-    fputs (spec, stderr);
-    fputs (": expected dirname/s[248] or dirname/([hw][0-9]+)*\n", stderr);
+    (void) fputs (spec, stderr);
+    (void) fputs (": expected dirname/s[248] or dirname/([hw][0-9]+)*\n",
+		  stderr);
     return 0;
   }
   if (c == spec ||
       ((c - spec) <= 2 && *spec == '.' &&
        ((c - spec) == 1 || spec[1] == '.'))) {
-    fputs (spec, stderr);
-    fputs (": thumbnail directory cannot be '', '.', or '..'\n", stderr);
+    (void) fputs (spec, stderr);
+    (void) fputs (": thumbnail directory cannot be '', '.', or '..'\n",
+		  stderr);
     return 0;
   }
 
   /* allocate the structure and copy the directory name */
   thumb = calloc (1, (c - spec) + sizeof *thumb);
   if (!thumb) {
-    fputs ("out of memory\n", stderr);
+    (void) fputs ("out of memory\n", stderr);
     return 0;
   }
   memcpy (thumb->thumbdir, spec, c - spec);
@@ -63,28 +65,28 @@ parse_spec (const char* spec)
   while (*c) {
     switch (*c) {
     default:
-      fputs (spec, stderr);
-      fputs (": parse error at `", stderr);
-      fputs (c, stderr);
-      fputs ("'\n", stderr);
+      (void) fputs (spec, stderr);
+      (void) fputs (": parse error at `", stderr);
+      (void) fputs (c, stderr);
+      (void) fputs ("'\n", stderr);
     error:
       free (thumb);
       return 0;
     case 'w':
       if (thumb->shrink) {
       excl:
-	fputs (spec, stderr);
-	fputs (": 's' is mutually exclusive with 'w' or 'h'\n", stderr);
+	(void) fputs (spec, stderr);
+	(void) fputs (": 's' is mutually exclusive with 'w' or 'h'\n", stderr);
 	goto error;
       }
       if (thumb->max_width) {
-	fputs (spec, stderr);
-	fputs (": at most one 'w', please\n", stderr);
+	(void) fputs (spec, stderr);
+	(void) fputs (": at most one 'w', please\n", stderr);
 	goto error;
       }
       thumb->max_width = strtoul (c + 1, &d, 0);
       if (thumb->max_width == 0 || thumb->max_width > 32767) {
-	fputs ("maximum width must be w1..w32767\n", stderr);
+	(void) fputs ("maximum width must be w1..w32767\n", stderr);
 	goto error;
       }
       c = d;
@@ -93,13 +95,13 @@ parse_spec (const char* spec)
       if (thumb->shrink)
 	goto excl;
       if (thumb->max_height) {
-	fputs (spec, stderr);
-	fputs (": at most one 'h', please\n", stderr);
+	(void) fputs (spec, stderr);
+	(void) fputs (": at most one 'h', please\n", stderr);
 	goto error;
       }
       thumb->max_height = strtoul (c + 1, &d, 0);
       if (thumb->max_height == 0 || thumb->max_height > 32767) {
-	fputs ("maximum height must be h1..h32767\n", stderr);
+	(void) fputs ("maximum height must be h1..h32767\n", stderr);
 	goto error;
       }
       c = d;
@@ -108,8 +110,8 @@ parse_spec (const char* spec)
       if (thumb->max_width || thumb->max_height)
 	goto excl;
       if (thumb->shrink) {
-	fputs (spec, stderr);
-	fputs (": at most one 's', please\n", stderr);
+	(void) fputs (spec, stderr);
+	(void) fputs (": at most one 's', please\n", stderr);
 	goto error;
       }
       thumb->shrink = strtoul (c + 1, &d, 0);
@@ -120,8 +122,8 @@ parse_spec (const char* spec)
       case 8:
 	break;
       default:
-	fputs (spec, stderr);
-	fputs (": shrink factor must be s2, s4 or s8\n", stderr);
+	(void) fputs (spec, stderr);
+	(void) fputs (": shrink factor must be s2, s4 or s8\n", stderr);
 	goto error;
       }
       break;
@@ -129,9 +131,9 @@ parse_spec (const char* spec)
   }
 
   if (!thumb->shrink && !thumb->max_width && !thumb->max_height) {
-    fputs (spec, stderr);
-    fputs (": shrink factor (s), width (w) or height (h) expected\n",
-	   stderr);
+    (void) fputs (spec, stderr);
+    (void) fputs (": shrink factor (s), width (w) or height (h) expected\n",
+		  stderr);
     goto error;
   }
 
